@@ -172,9 +172,8 @@ int gotoh_pair_wise_lgp ( Alignment *A, int *ns, int **l_s, Constraint_list *CL)
 int test_pair_wise (Alignment *A, int *ns, int **l_s, Constraint_list *CL);
 
 int glocal2_pair_wise (Alignment *A,int*ns, int **ls,Constraint_list *CL);
-int gotoh_pair_wise_lgp_sticky ( Alignment *A, int *ns, int **l_s, Constraint_list *CL);
 int linked_pair_wise ( Alignment *A, int *ns, int **l_s, Constraint_list *CL);
-int clinked_pair_wise ( Alignment *A, int *ns, int **l_s, Constraint_list *CL);
+int linked_pair_wise_collapse ( Alignment *A, int *ns, int **l_s, Constraint_list *CL);
 int cl2pair_list_ecl_ext_pc ( Alignment *A, int *ns, int **ls, Constraint_list *CL, int ***list_in, int *n_in);
 void free_proba_pair_wise();
 
@@ -426,7 +425,7 @@ float sap2_neighborhood_match (Constraint_list *CL, int s1, int s2, int r1, int
 /*                                                                                           */
 /*********************************************************************************************/
 Alignment * analyse_pdb ( Alignment *A, Alignment *ST, char *filename);
-Alignment * msa2struc_dist ( Alignment *A, Alignment *ST, char *filename, int gapped);
+Alignment * msa2struc_dist ( Alignment *A, Alignment *ST, char *filename, int gapped, int min_ncol);
 float **** analyse_pdb_residues ( Alignment *A, Constraint_list *CL, Pdb_param *pdb_param);
 
 float square_atom ( Atom *X);
@@ -510,7 +509,7 @@ Alignment * categories_evaluate_output               ( Alignment *IN,Constraint_
 Alignment * matrix_evaluate_output               ( Alignment *IN,Constraint_list *CL);
 Alignment * sar_evaluate_output ( Alignment *IN,Constraint_list *CL);
 Alignment * boxshade_evaluate_output ( Alignment *IN,Constraint_list *CL, int T);
-
+Alignment * triplet_coffee_evaluate_output          ( Alignment *IN,Constraint_list *CL);
 Alignment * fast_coffee_evaluate_output          ( Alignment *IN,Constraint_list *CL);
 
 int slow_coffee_evaluate_sub_aln         ( Alignment *IN,int *ns, int **ls, Constraint_list *CL);
@@ -812,11 +811,11 @@ NT_node pavie_seq2pavie_tree ( Sequence *S, char *mat, char *mode);
 int **pavie_seq2trained_pavie_mat(Sequence *S, char *param);
 int pavie_pair_wise (Alignment *A,int *ns, int **l_s,Constraint_list *CL );
 Sequence *pavie_seq2noisy_seq (Sequence *S, int val,char *subst); 
-/*********************************COPYRIGHT NOTICE**********************************/
+/******************************COPYRIGHT NOTICE*******************************/
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Thu Jun 24 13:19:29 CEST 2010. */
+/*Fri Feb 18 08:27:45 CET 2011 - Revision 596. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
@@ -840,4 +839,4 @@ Sequence *pavie_seq2noisy_seq (Sequence *S, int val,char *subst);
 /**/
 /**/
 /*	*/
-/*********************************COPYRIGHT NOTICE**********************************/
+/******************************COPYRIGHT NOTICE*******************************/
