@@ -91,7 +91,7 @@ int apdb ( int argc, char *argv[])
 	
 	char *pdb_db;
 	char *prot_db;
-
+	int min_ncol;
 
 	argv=standard_initialisation (argv, &argc);
 	
@@ -824,7 +824,22 @@ declare_name (prot_db);
 			    /*Min_value*/ "any"         ,\
 			    /*Max Value*/ "any"          \
 		   );
-
+ get_cl_param(							\
+			    /*argc*/      argc          ,\
+			    /*argv*/      argv          ,\
+			    /*output*/    &le           ,\
+			    /*Name*/      "-min_ncol"    ,\
+			    /*Flag*/      &garbage      ,\
+			    /*TYPE*/      "D"         ,\
+			    /*OPTIONAL?*/ OPTIONAL      ,\
+			    /*MAX Nval*/  1             ,\
+			    /*DOC*/       "minimum number of columns (negative: fraction)"          ,\
+ 			    /*Parameter*/&min_ncol       ,\
+	 		    /*Def 1*/    "4"      ,\
+			    /*Def 2*/    "1"      ,\
+			    /*Min_value*/ "any"         ,\
+			    /*Max Value*/ "any"          \
+		   );
  // set the correct mode:
  if ( strm (argv[0], "trmsd"))sprintf (mode, "trmsd");
    
@@ -954,7 +969,7 @@ declare_name (prot_db);
 		  }
 		else if ( strm (mode, "msa2tree") || strm (mode, "trmsd"))
 		  {
-		    EA=msa2struc_dist ( A, EA,F->name, gapped);
+		    EA=msa2struc_dist ( A, EA,F->name, gapped, min_ncol);
 		  }
 		le=display_output_filename ( le, "APDB_RESULT", "APDB_RESULT_FORMAT_01", apdb_outfile, CHECK);
 		
@@ -2142,7 +2157,7 @@ int column_is_suitable4trmsd(int col1,Alignment *A, int **pos, Pdb_param *PP, Co
 
 
 NT_node trmsdmat2tree (float **dm, int **count,Alignment *A);
-Alignment * msa2struc_dist ( Alignment *A, Alignment *ST, char *results, int gapped)
+Alignment * msa2struc_dist ( Alignment *A, Alignment *ST, char *results, int gapped, int min_ncol4trmsd)
      {
 
        int **pos, c;
@@ -2152,7 +2167,7 @@ Alignment * msa2struc_dist ( Alignment *A, Alignment *ST, char *results, int gap
 	 float ****distances;
 	 float **dm,**tdm;
 	 int **count,**tcount;
-	
+	 int print_subtrees=0;
 	 float min, max;
 	 
 	      /*Distances[Nseq][len_aln][4]
@@ -2177,9 +2192,9 @@ Alignment * msa2struc_dist ( Alignment *A, Alignment *ST, char *results, int gap
 	 float nrapdb, rapdb;
 	 Alignment *BA=NULL;
 	 NT_node *T0,*T1,*T2,*PT, *POS;
-	 NT_node BT0, BT10,BT50, BT100,RBT;
+	 NT_node BT0, BT10,BT50, BT100=NULL,RBT;
 	 char **pair_pos_list;
-	 int min_ncol4trmsd=4;
+	 
 	 int ntree=0, ntree2;
 	 
 	 Alignment *B;
@@ -2196,21 +2211,32 @@ Alignment * msa2struc_dist ( Alignment *A, Alignment *ST, char *results, int gap
 	 int **score;
 	 int proceed=1;
 	 int **lc;
+	 int used;
+	 
+	 if (min_ncol4trmsd<0)
+	   {
+	     min_ncol4trmsd*=-1;
+	     min_ncol4trmsd=(min_ncol4trmsd*A->len_aln)/100;
+	   }
+	 else if ( min_ncol4trmsd>=A->len_aln)
+	   {
+	     min_ncol4trmsd=A->len_aln-1;
+	   }
 
 	 lc=declare_int (A->nseq, 2);
 	 for (a=0; a<A->nseq; a++)lc[a][0]=a;
 	 
 	 declare_name(tot_pos_list);
-	 sprintf ( tot_pos_list, "%s.tot_pos_list", results);
+	 sprintf ( tot_pos_list, "%s.struc_tree.list", results);
 
 	 declare_name(consense_file);
-	 sprintf (consense_file, "%s.consense_output", results);
+	 sprintf (consense_file, "%s.struc_tree.consense_output", results);
 
 	 declare_name(pos_list);
 	 sprintf ( pos_list, "%s.pos_list", results);
 
 	 declare_name(struc_tree0);
-	 sprintf ( struc_tree0, "%s.struc_tree_full",results);
+	 sprintf ( struc_tree0, "%s.struc_tree.consensus",results);
 
 	 declare_name(struc_tree10);
 	 sprintf ( struc_tree10, "%s.struc_tree10",results);
@@ -2234,18 +2260,28 @@ Alignment * msa2struc_dist ( Alignment *A, Alignment *ST, char *results, int gap
 	 CL=A->CL;
 
 	 //Check all sequences have a PDB structure
-	 for (a=0; a<A->nseq; a++)
+
+	 for (used=0,a=0; a<A->nseq; a++)
 	   {
 	     if ( ! seq2P_template_file(A->S,a))
 	       {
-		 fprintf ( stderr, "\n--- ERROR: %s has no structural template. All sequence in the MSA must have a known structure [FATAL]\n", (A->name[a]));
-		 proceed=0;
+		 add_warning (stderr, "Sequence %s removed from the dataset [No Usable Structure]", A->name[a]);
+	       }
+	     else
+	       {
+		 if (used!=a)
+		   {
+		     sprintf (A->name[used], "%s", A->name[a]);
+		     sprintf (A->seq_al[used], "%s", A->seq_al[a]);
+		     for (b=0; b<4; b++)A->order[used][b]=A->order[a][b];
+		   }
+		 used++;
 	       }
 	   }
-
-	
-	 if (!proceed)
-	    printf_exit (EXIT_FAILURE, stderr, "\n\n---- ERROR: All provided sequences must have a valid PDB identifier [FATAL:tRMSD-%s]\n\n", PROGRAM);
+	 
+	 A->nseq=used;
+	 
+	 if (A->nseq<2)myexit (fprintf_error(stderr, "Two sequences at least must have a known structure"));
 	 
 	 for ( s1=0; s1< (A->S)->nseq; s1++)
 	   if ( CL->T[s1]){PP=(CL->T[s1])->pdb_param;break;}
@@ -2265,26 +2301,22 @@ Alignment * msa2struc_dist ( Alignment *A, Alignment *ST, char *results, int gap
 	 PP->maximum_distance=1000;
 	 sprintf ( PP->local_mode, "sphere");
 	 
-	 
 	 while ((npos=aln2ncol4trmsd(A,pos,CL,lc))<min_ncol4trmsd && A->nseq>1)
 	   {
 	     
 	     sort_int_inv (lc,2, 1, 0,A->nseq-1);
-	     fprintf ( stdout, "\nRemove Sequence [%s] that contains %d un-suitable positions\n", A->name[lc[0][0]], lc[0][1]);
+	     add_information (stderr, "Remove Sequence [%s] that contains %d un-suitable positions", A->name[lc[0][0]], lc[0][1]);
 	     A=remove_seq_from_aln (A, A->name[lc[0][0]]);
 	     ungap_aln (A);
 	     pos=aln2pos_simple (A, A->nseq);
 	   }
 	 if (!A->nseq)
 	   {
-	     fprintf ( stderr, "\nERROR: No suitable pair of column supporting a tree [FATAL]\n");
-	     exit (EXIT_SUCCESS);
+	     myexit (fprintf_error(stderr,"No suitable pair of column supporting a tree"));
 	   }
 	 else
-	    fprintf ( stdout, "\n---- Number of usable positions: %d [%.2f %%]\n", npos, ((float)npos*100)/(float)A->len_aln);
+	    fprintf ( stderr, "\n---- Number of usable positions: %d [%.2f %%]\n", npos, ((float)npos*100)/(float)A->len_aln);
 
-	 print_aln (A);
-	 HERE ("Gapped=%d", gapped);
 	 tl=vfopen (tot_pos_list, "w");
 	 for (ncol=0,ntree=0, col1=0; col1< A->len_aln; col1++)
 	   {
@@ -2337,41 +2369,47 @@ Alignment * msa2struc_dist ( Alignment *A, Alignment *ST, char *results, int gap
 	 if (!ntree){fprintf ( stderr, "\nERROR: No suitable pair of column supporting a tree [FATAL]\n"); exit (EXIT_SUCCESS);}
 	 
 	 score=treelist2avg_treecmp (T1, NULL);
-	 display_output_filename( stdout,"TreeList","newick",tot_pos_list, CHECK);
+	 display_output_filename( stderr,"TreeList","newick",tot_pos_list, CHECK);
 	 
 	 if (treelist_file2consense (tot_pos_list, NULL, consense_file))
 	   {
-	     display_output_filename( stdout,"ConsenseTree","phylip",consense_file, CHECK);
+	     display_output_filename( stderr,"ConsenseTree","phylip",consense_file, CHECK);
 	   }
 	 else
 	   {
 	     fprintf ( stderr, "\nPhylip is not installed: the program could not produce the consense output. This is not mandatory but useful");
 	   }
-		  
-	 if ( (BT0=trmsdmat2tree (tdm, tcount, A)))
+
+	 //consensus tree
+	
+	 if ((BT100=treelist2filtered_bootstrap (T1, NULL,score, 1.0)))
+	       {
+		 vfclose (print_tree (BT100,"newick", vfopen (struc_tree0, "w")));
+		 display_output_filename( stderr,"Tree","newick",struc_tree0, CHECK);
+	       }
+	 if (print_subtrees)
 	   {
-	     vfclose (print_tree (BT0,"newick", vfopen (struc_tree0, "w")));
-	     display_output_filename( stdout,"Tree","newick",struc_tree0, CHECK);
+	    
+	     if ( (BT0=trmsdmat2tree (tdm, tcount, A)))
+	       {
+		 vfclose (print_tree (BT0,"newick", vfopen (struc_tree0, "w")));
+		 display_output_filename( stderr,"Tree","newick",struc_tree0, CHECK);
+	       }
+	     if ((BT10=treelist2filtered_bootstrap (T1, NULL,score, 0.1)))
+	       {
+		 vfclose (print_tree (BT10,"newick", vfopen (struc_tree10, "w")));
+		 display_output_filename( stderr,"Tree","newick",struc_tree10, CHECK);
+	       }
+	     
+	     if ((BT50=treelist2filtered_bootstrap (T1, NULL, score,0.5)))
+	       {
+		 vfclose (print_tree (BT50,"newick", vfopen (struc_tree50, "w")));
+		 display_output_filename( stderr,"Tree","newick",struc_tree50, CHECK);
+	       }
 	   }
 
-	 if ((BT10=treelist2filtered_bootstrap (T1, NULL,score, 0.1)))
-	   {
-	     vfclose (print_tree (BT10,"newick", vfopen (struc_tree10, "w")));
-	     display_output_filename( stdout,"Tree","newick",struc_tree10, CHECK);
-	   }
-	 
-	 if ((BT50=treelist2filtered_bootstrap (T1, NULL, score,0.5)))
-	   {
-	     vfclose (print_tree (BT50,"newick", vfopen (struc_tree50, "w")));
-	     display_output_filename( stdout,"Tree","newick",struc_tree50, CHECK);
-	   }
-	 
-	 if ((BT100=treelist2filtered_bootstrap (T1, NULL,score, 1.0)))
-	   {
-	     vfclose (print_tree (BT100,"newick", vfopen (struc_tree100, "w")));
-	     display_output_filename( stdout,"Tree","newick",struc_tree100, CHECK);
-	   }
 	 
+	 if (!BT100)BT100=treelist2filtered_bootstrap (T1, NULL,score, 1.0);
 	 
 	 RBT=BT100;
 	 if (RBT)
@@ -2380,13 +2418,12 @@ Alignment * msa2struc_dist ( Alignment *A, Alignment *ST, char *results, int gap
 	     for (a=0; a<A->len_aln; a++)
 	       {
 		 int score;
-		 Tree_sim *S;
+		 Tree_sim *S=NULL;
 		 
 		 if (POS[a])
 		   {
 		     S=tree_cmp (POS[a], RBT);
 		     score=S->uw/10;
-		     vfree (S);
 		   }
 		 else
 		   {
@@ -2404,12 +2441,15 @@ Alignment * msa2struc_dist ( Alignment *A, Alignment *ST, char *results, int gap
 			 B->seq_al[b][a]=S->uw/10;
 		       }
 		   }
+		 if (S)vfree (S);
 	       }
 	     
 	     output_format_aln ("score_html", A,B,color_struc_tree);
-	     display_output_filename( stdout,"Colored MSA","score_html",color_struc_tree, CHECK);
+	     display_output_filename( stderr,"Colored MSA","score_html",color_struc_tree, CHECK);
 	     free_aln (BA);
+	     fprintf ( stderr, "\n");
 	   }
+	 fprintf ( stderr, "\n");
 	 free_int (pos, -1);
 	 exit (EXIT_SUCCESS);
 	 return NULL;
@@ -2783,11 +2823,11 @@ int display_rna_ss ( int n, char *seq, char *st, FILE *fp)
     }
   return n;
 }
-/*********************************COPYRIGHT NOTICE**********************************/
+/******************************COPYRIGHT NOTICE*******************************/
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Thu Jun 24 13:19:29 CEST 2010. */
+/*Fri Feb 18 08:27:45 CET 2011 - Revision 596. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
@@ -2811,4 +2851,4 @@ int display_rna_ss ( int n, char *seq, char *st, FILE *fp)
 /**/
 /**/
 /*	*/
-/*********************************COPYRIGHT NOTICE**********************************/
+/******************************COPYRIGHT NOTICE*******************************/
