@@ -96,7 +96,7 @@ char *    get_string_type   (char *S)
 	      sprintf ( type, "PROTEIN");
 	    
 	  }
-	else if ( dna>98 && rna>10)sprintf ( type, "RNA");
+	else if ( dna>98 && rna>0)sprintf ( type, "RNA");
 	else if ( dna>98)sprintf ( type, "DNA");
 	else sprintf ( type, "PROTEIN");
 	
@@ -332,6 +332,9 @@ int ** read_matrice (char *mat_name_in)
 	else if (strm(mat_name, "ralpha_mat" ))vector=ralpha_mat;
 	else if (strm(mat_name, "rcoil_mat" ))vector=rcoil_mat;
 	else if (strm (mat_name, "jtttm250mt"))vector=jtttm250mt;
+	
+	else if (strm (mat_name, "promoter_tf1"))vector=promoter_tf1;
+	else if (strm (mat_name, "blosumR"))vector=blosumR;
 
 	/*Header Matrices*/
 	if(vector)
@@ -1367,7 +1370,7 @@ FILE_format* vfopen_html ( char *name)
 
       fprintf(fhtml->fp,"<html>\n<style>\n");
      
-      fprintf(fhtml->fp,"SPAN { font-family: courier new, courier-new, courier; font-weight: bold; font-size: %dpt;}\n", fhtml->font);
+      fprintf(fhtml->fp,"SPAN { font-family: courier new, courier-new, courier, monospace; font-weight: bold; font-size: %dpt;}\n", fhtml->font);
       fprintf(fhtml->fp,"SPAN { line-height:100%%}\n");
       fprintf(fhtml->fp,"SPAN {	white-space: pre}\n");
       
@@ -1498,11 +1501,11 @@ int       output_seq_reliability_ascii     ( Alignment *B,Alignment *S, char *na
   return 1;
 }
   
-/*********************************COPYRIGHT NOTICE**********************************/
+/******************************COPYRIGHT NOTICE*******************************/
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Thu Jun 24 13:19:29 CEST 2010. */
+/*Fri Feb 18 08:27:45 CET 2011 - Revision 596. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
@@ -1526,4 +1529,4 @@ int       output_seq_reliability_ascii     ( Alignment *B,Alignment *S, char *na
 /**/
 /**/
 /*	*/
-/*********************************COPYRIGHT NOTICE**********************************/
+/******************************COPYRIGHT NOTICE*******************************/
