@@ -36,8 +36,8 @@ int *** duplicate_residue_index (int ***r)
   nr=vcalloc ( d1, sizeof (int**));
   for (a=0; a<d1; a++)
     {
-      d2=read_array_size_new (r[a]);
-      nr[a]=vcalloc ( d2, sizeof (int*));
+      d2=read_array_size_new (r[a])-1;
+      nr[a]=vcalloc ( d2+1, sizeof (int*));
       for (b=0; b<d2; b++)
 	{
 	  d3=read_array_size_new (r[a][b]);
@@ -55,7 +55,7 @@ int *** declare_residue_index (Sequence *S)
   r=vcalloc ( S->nseq, sizeof (int**));
   for ( a=0; a<S->nseq; a++)
     {
-      r[a]=vcalloc (S->len[a]+1, sizeof (int*));
+      r[a]=vcalloc (S->len[a]+2, sizeof (int*));//The empty terminator makes a scan possible without knowing len
       for ( b=0; b<=S->len[a]; b++)
 	{
 	  r[a][b]=vcalloc ( 1, sizeof (int));
@@ -159,7 +159,8 @@ Constraint_list *copy_constraint_list (Constraint_list *CL, int mode)
     
 
       S=(mode==HARD_COPY)?duplicate_sequence (CL->S):CL->S;
- 
+      
+      
       if (mode==HARD_COPY)
 	NCL=declare_constraint_list (S, NULL, NULL,0, NULL, NULL);
       else
@@ -168,10 +169,23 @@ Constraint_list *copy_constraint_list (Constraint_list *CL, int mode)
 	  NCL[0]=CL[0];
 	}
       
-      NCL->S=S;
+      
       NCL->copy_mode=mode;
       if (mode==SOFT_COPY)NCL->pCL=CL;
+      NCL->S=S;
+      /*master*/
+      if (mode==HARD_COPY && CL->master)
+	{NCL->master=vcalloc ( S->nseq, sizeof(int));
+	for ( a=0; a< S->nseq; a++)
+	  NCL->master[a]=CL->master[a];
+	}
+      else if (mode==SOFT_COPY)
+	{
+	  NCL->seq_for_quadruplet=CL->seq_for_quadruplet;
+	}
+      NCL->o2a_byte=CL->o2a_byte;
       
+      /*struc List*/
       NCL->STRUC_LIST=(mode==HARD_COPY)?duplicate_sequence (CL->STRUC_LIST):CL->STRUC_LIST;
       sprintf ( NCL->align_pdb_param_file, "%s", CL->align_pdb_param_file);
       sprintf ( NCL->align_pdb_hasch_mode, "%s", CL->align_pdb_hasch_mode);
@@ -600,6 +614,8 @@ Sequence * declare_sequence ( int min, int max, int nseq)
     LS->max_nseq=nseq;
     LS->type=vcalloc(30, sizeof (char));
     LS->T=declare_arrayN(2, sizeof (Template), nseq, 1);
+    
+    
     LS->dc=declare_int (nseq, 2);
     return LS;
     }
@@ -623,6 +639,7 @@ Sequence * realloc_sequence   (Sequence *OUT, int new_nseq, int max_len)
       
       OUT->T=(Template**)realloc_arrayN (2, (void **)OUT->T,sizeof (Template), new_nseq, 1);
       OUT->dc=(int **)realloc_arrayN (2, (void **)OUT->dc,sizeof (int), new_nseq, 2);
+      
       OUT->max_nseq=new_nseq;
       return OUT;
     }
@@ -643,12 +660,13 @@ Sequence * duplicate_sequence (Sequence *S )
 	      sprintf ( LS->file[b], "%s", S->file[a]);	
 	      if ( S->seq_comment && S->seq_comment[a])sprintf ( LS->seq_comment[b], "%s", S->seq_comment[a]);
 	      if ( S->aln_comment && S->aln_comment[a])sprintf ( LS->aln_comment[b], "%s", S->aln_comment[a]);
-	      if ( S->seq && S->seq[a])sprintf  ( LS->seq[b], "%s", S->seq[a]);
+	      if ( S->seq && S->seq[a])sprintf  ( LS->seq[b],  "%s", S->seq[a]);
 	      if ( S->name&& S->name[a])sprintf ( LS->name[b], "%s", S->name[a]);
 	      LS->dc[b][0]=S->dc[a][0];
 	      LS->dc[b][1]=S->dc[a][1];
 	      LS->len[b]=S->len[a];
 	      LS->T[b][0]=S->T[a][0];
+	      
 	      b++;
 	      
 	    }
@@ -658,7 +676,7 @@ Sequence * duplicate_sequence (Sequence *S )
     LS->min_len=S->min_len;
     LS->nseq=b;
 
-    if ( S->W)LS->W=duplicate_weights (S->W);
+    if (S->W)LS->W=duplicate_weights (S->W);
     sprintf ( LS->type, "%s", S->type);
     sprintf ( LS->template_file, "%s", S->template_file);
     LS->max_nseq=S->nseq;
@@ -683,6 +701,7 @@ void free_sequence ( Sequence *LS, int nseq)
 	vfree (LS->type);
 	vfree (LS->len);
 	free_weights (LS->W);
+	
 	vfree (LS);
 
 	}
@@ -836,6 +855,7 @@ Alignment* copy_aln ( Alignment *A, Alignment *B)
 
 	    B->score_aln=A->score_aln;
 	    B->score=A->score;
+	    B->ibit=A->ibit;
 	    B->cpu=A->cpu;
 	    B->finished=A->finished;
 
@@ -1123,17 +1143,20 @@ Sequence* free_aln ( Alignment *LA){ return free_Alignment(LA);}
 Alignment *free_data_in_aln (Alignment *A)
 {
   //Frees only the sequence data (keeps profile information)
-  free_char (A->seq_al, -1);
-  free_char (A->seq_comment, -1);
-  free_char (A->aln_comment, -1);
-  free_char (A->name, -1);
-  free_char (A->expanded_order, -1);
-  free_char (A->seq_al, -1);
-  free_int (A->order, -1);
-  free_int (A->seq_cache, -1);
-  free_int (A->cdna_cache, -1);
-  free_int (A->score_res, -1);
+  A->seq_al=free_char (A->seq_al, -1);
+  A->seq_comment=free_char (A->seq_comment, -1);
+  A->aln_comment=free_char (A->aln_comment, -1);
+  A->name=free_char (A->name, -1);
+  A->expanded_order=free_char (A->expanded_order, -1);
+  
+  A->order=free_int (A->order, -1);
+  A->seq_cache=free_int (A->seq_cache, -1);
+  A->cdna_cache=free_int (A->cdna_cache, -1);
+  A->score_res=free_int (A->score_res, -1);
   free_sequence (A->S, -1);
+  A->S=NULL;
+  return A;
+  
 }
 Sequence* free_Alignment ( Alignment *LA)
 	{
@@ -1888,11 +1911,11 @@ Fname *free_fname ( Fname *F)
    vfree (F->suffix);
    return NULL;
    }
-/*********************************COPYRIGHT NOTICE**********************************/
+/******************************COPYRIGHT NOTICE*******************************/
 /* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Thu Jun 24 13:19:29 CEST 2010. */
+/*Fri Feb 18 08:27:45 CET 2011 - Revision 596. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
@@ -1916,4 +1939,4 @@ Fname *free_fname ( Fname *F)
 /**/
 /**/
 /*	*/
-/*********************************COPYRIGHT NOTICE**********************************/
+/******************************COPYRIGHT NOTICE*******************************/
